@@ -1,6 +1,6 @@
 var searchData=
 [
   ['radians_0',['radians',['../classsf_1_1Angle.html#a8738691f6b62b7fcebf5c7e9b47c4a24',1,'sf::Angle']]],
-  ['rendertarget_1',['RenderTarget',['../classsf_1_1Drawable.html#aa5afc6f82b7b587ed5ada4d227ce32aa',1,'sf::Drawable::RenderTarget'],['../classsf_1_1Texture.html#aa5afc6f82b7b587ed5ada4d227ce32aa',1,'sf::Texture::RenderTarget']]],
+  ['rendertarget_1',['RenderTarget',['../classsf_1_1Drawable.html#aa5afc6f82b7b587ed5ada4d227ce32aa',1,'sf::Drawable::RenderTarget()'],['../classsf_1_1Texture.html#aa5afc6f82b7b587ed5ada4d227ce32aa',1,'sf::Texture::RenderTarget']]],
   ['rendertexture_2',['RenderTexture',['../classsf_1_1Texture.html#a2548fc9744f5e43e0276d5627ca178de',1,'sf::Texture']]]
 ];
